Centralized place for security controls
-------

**Description:**

Whenever security controls do not have a centralized implementation there is a high
probability for bugs or security issues being hidden into your application due to the loss
of abstraction and duplication.

 
**Solution:**

Make sure all your different type of security controls have a centralized place of implementation.
Also verify that error handling logic in security controls denies access by default.
 
